@@ -44,4 +44,8 @@ class Bash(Generic):
             config = '~/.bashrc'
         else:
             config = 'bash config'
-        return 'eval $(thefuck --alias)', config
+
+        return self._create_shell_configuration(
+            content=u'eval $(thefuck --alias)',
+            path=config,
+            reload=u'source {}'.format(config))
