@@ -45,4 +45,7 @@ class Zsh(Generic):
             return ''
 
     def how_to_configure(self):
-        return 'eval $(thefuck --alias)', '~/.zshrc'
+        return self._create_shell_configuration(
+            content=u'eval $(thefuck --alias)',
+            path='~/.zshrc',
+            reload='source ~/.zshrc')
