@@ -40,8 +40,8 @@ class Command(object):
 
     def __eq__(self, other):
         if isinstance(other, Command):
-            return (self.script, self.stdout, self.stderr) \
-                   == (other.script, other.stdout, other.stderr)
+            return ((self.script, self.stdout, self.stderr)
+                    == (other.script, other.stdout, other.stderr))
         else:
             return False
 
@@ -159,12 +159,12 @@ class Rule(object):
 
     def __eq__(self, other):
         if isinstance(other, Rule):
-            return (self.name, self.match, self.get_new_command,
-                    self.enabled_by_default, self.side_effect,
-                    self.priority, self.requires_output) \
-                   == (other.name, other.match, other.get_new_command,
-                       other.enabled_by_default, other.side_effect,
-                       other.priority, other.requires_output)
+            return ((self.name, self.match, self.get_new_command,
+                     self.enabled_by_default, self.side_effect,
+                     self.priority, self.requires_output)
+                    == (other.name, other.match, other.get_new_command,
+                        other.enabled_by_default, other.side_effect,
+                        other.priority, other.requires_output))
         else:
             return False
 
@@ -172,9 +172,9 @@ class Rule(object):
         return 'Rule(name={}, match={}, get_new_command={}, ' \
                'enabled_by_default={}, side_effect={}, ' \
                'priority={}, requires_output)'.format(
-            self.name, self.match, self.get_new_command,
-            self.enabled_by_default, self.side_effect,
-            self.priority, self.requires_output)
+                   self.name, self.match, self.get_new_command,
+                   self.enabled_by_default, self.side_effect,
+                   self.priority, self.requires_output)
 
     @classmethod
     def from_path(cls, path):
